:
# NAME:
#	ksh.kshrc - global initialization for ksh 
#
# DESCRIPTION:
#	Each invocation of /bin/ksh processes the file pointed
#	to by $ENV (usually $HOME/.kshrc).
#	This file is intended as a global .kshrc file for the
#	Korn shell.  A user's $HOME/.kshrc file simply requires
#	the line:
#		. /etc/ksh.kshrc
#	at or near the start to pick up the defaults in this
#	file which can then be overridden as desired.
#
# SEE ALSO:
#	$HOME/.kshrc
#
#
# AUTHOR:
#	Simon J. Gerraty <sjg@zen.void.oz.au>

# RCSid:
#	$Id: ksh.kshrc,v 1.7 1996/01/03 10:45:29 sjg Exp $
#
#	@(#)Copyright (c) 1991 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 

case "$-" in
*i*)	# we are interactive
	# we may have su'ed so reset these
	# NOTE: SCO-UNIX doesn't have whoami,
	#	install whoami.sh
	USER=`whoami 2>/dev/null`
	USER=${USER:-`id | sed 's/^[^(]*(\([^)]*\)).*/\1/'`}
	test -w / && PS1S='# '
	PS1S=${PS1S:-'$ '}
	HOSTNAME=${HOSTNAME:-`uname -n`}
	# this yuk, is to work around failings of *BSD's
	# posix shell, which uses $ENV too, but can't handle
	# ksh'isms and does not ignore code bounded by
	# if [ "$RANDOM" != "$RANDOM" ]
	HOST=`IFS=.; set $HOSTNAME; echo $1`
	PROMPT="$USER:!$PS1S"
	PPROMPT='$USER:${PWD##*?/}:!'"$PS1S"
	PS1=$PPROMPT
	# $TTY is the tty we logged in on,
	# $tty is that which we are in now (might be pty)
	# for Solaris and some others, basename won't do
	tty=`tty | sed 's,/dev/,,'`
	TTY=${TTY:-$tty}

	set -o emacs		# doesn't everyone prefer it?

	alias h='fc -l | more'
	_cd() { "cd" $*; }
	# the PD ksh is not 100% compatible
	case "$KSH_VERSION" in
	*PD*)	# PD ksh
	  case "$KSH_VERSION" in
	  *5.*)	[ -r /etc/ksh.cdhist ] && . /etc/ksh.cdhist
	  esac
		case "$TERM" in
		pc3|xterm*)
			# bind arrow keys
			bind '^[['=prefix-2
			bind '^XA'=up-history
			bind '^XB'=down-history
			bind '^XC'=forward-char
			bind '^XD'=backward-char
			;;
		esac
		;;
	*)	# real ksh ?
		[ -r /etc/ksh.cdhist ] && . /etc/ksh.cdhist
		set -o trackall
		case "$TERM" in
		vt*|xterm*)
		  # Kevin Gallagher in comp.emacs!
		  alias	 __A=^P				  # up arrow
		  alias	 __B=^N				  # down arrow
		  alias	 __C=^F				  # right arrow
		  alias	 __D=^B				  # left arrow
		  ;;
		esac
		;;
	esac
	case "$TERM" in
	sun*)
		if [ "$tty" != console ]; then
			# ilabel
			ILS='\033]L'; ILE='\033\\'
			# window title bar
			WLS='\033]l'; WLE='\033\\'
		fi
		;;
	xterm*)
		ILS='\033]1;'; ILE='\007'
		WLS='\033]2;'; WLE='\007'
		;;
	hpterm*)
		# slightly different model, 
		# so define the functions ourselves.
		ILS=label
		ilabel() { _a="$@"; print -n "\033&f-1k${#_a}D${_a}"; }
		label() { _a="$@"; print -n "\033&f0k${#_a}D${_a}"; }
		;;
	*)	;;
	esac
	# do we want window decorations?
	if [ "$ILS" ]; then
		if [ "$ILS" != label ]; then
			ilabel () { print -n "${ILS}$*${ILE}"; }
			label () { print -n "${WLS}$*${WLE}"; }
		fi
		alias stripe='label "$USER@$HOST ($tty) - $PWD"'
		alias istripe='ilabel "$USER@$HOST ($tty)"'

		# make sure title bar is updated
		w_cd() { _cd "$@"; eval stripe; }
		alias cd=w_cd

		# these are commands that take us elsewhere...
		# so istripe too.
		for c in ${W_CMDS:-su rlogin telnet kermit stelnet ftp tip}
		do
		  eval "w_$c() { \"$c\" \"\$@\"; eval istripe; eval stripe; }"
		  eval alias $c=w_$c
		done

		eval stripe
		eval istripe
		PS1=$PROMPT
	fi
	alias quit=exit
	alias cls=clear
	alias logout=exit
	alias bye=exit
	alias p='ps -l'
	alias j=jobs
	alias o='fg %-'
	alias ls='ls -gCF'

# add your favourite aliases here
	alias rsize='eval `"resize"`'
	alias resize=rsize
	
	OS=${OS:-`uname`}
	OSREL=${OSREL:-`uname -r`}
	case $OS in
	HP-UX)
		alias ls='ls -CF'
		;;
	*BSD)
		alias df='df -k'
		alias du='du -k'
		;;
	SunOS)
		case $OSREL in
		5*)
                	alias ls='ls -CF'
			alias df='df -k'
			alias rsize='eval `"resize"`; stty rows $LINES'
			;;
		esac
		;;
	esac	

	case "$TERM" in
	sun*|xterm*)
		case $tty in
		pts/*|tty[p-w]*)		
			case "$DISPLAY" in
			"")
				DISPLAY="`who | grep $TTY | sed -n 's/.*(\([^:)]*\)[:)].*/\1/p' | sed 's/\([a-zA-Z][^.]*\).*/\1/'`:0"
				;;
			esac
			;;
		esac
		export DISPLAY
		;;
	esac
;;
*)	# non-interactive
;;
esac
# commands for both interactive and non-interactive shells

. /etc/add_path.sh
